Description Usage Arguments Examples
For a matrix, computes the ratios of the supplied margin (1 = rows, 2 = cols). Otherwise, computes the ratios of the elements.
1 2 3 4 5 6 7 8 9 10 11 12 13 | pairwise_ratios(x, ..., f = `/`, filter = TRUE, set_names = TRUE, sep = ":")
## Default S3 method:
pairwise_ratios(x, f = `/`, filter = TRUE, set_names = TRUE, sep = ":")
## S3 method for class 'matrix'
pairwise_ratios(x, margin, f = `/`, filter = TRUE, set_names = TRUE, sep = ":")
## S3 method for class 'otu_table'
pairwise_ratios(x, margin = "taxa", f = `/`, filter = TRUE, sep = ":")
## S3 method for class 'phyloseq'
pairwise_ratios(x, margin = "taxa", f = `/`, filter = TRUE, sep = ":")
|
x |
A vector or matrix |
f |
Vectorized binary function applied to numerator and denominator |
filter |
Whether to filter out redundant pairs |
set_names |
Whether to set names for the pairs |
sep |
Seperator for pair names |
margin |
Margin (1 = rows, 2 = cols) of matrix x to compute ratios of |
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.